=========
ChangeLog
=========


v0.4.2
======

* Removed `distribute` dependency


v0.4.0
======

* Corrected inclusion of ``VERSION.txt`` in manifest


v0.3.0
======

* First tagged release
* Fixed issue #1
